@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "3.3.91"
+version     = "3.3.92"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/jd/orca/bld"
+prefix      = "/home/jd/GNOME/checkouts/orca/bld"
 
 # The package name (should be "orca").
 #
